#!/bin/sh 
###  don't touch next  line:   test is needed for sge job.
test  $# -eq  0  &&    source ../confirm.inc

#------------may be you don't need touch next
TOPDIR=$COSMOSTOP/UserHook/DisParaRescue
export TOPDIR
#   dir to store execution command (ssh)  or submit command (sge)
EXECDIR=$TOPDIR/FleshBasic/Exec
export EXECDIR
#   id to be used for the command file mentioned above. (must start with A-z)
EXECID=p15cos1.0
export EXECID
#     where param001 etc exist
PARAMDIR=$TOPDIR/FleshBasic/ParamDir
export PARAMDIR
#     where to put  files createdd by each host
#     /tmp/$USER/ is better
OUTDIR=$TOPDIR/Assemble/OutDir
#OUTDIR=/tmp/$USER
export OUTDIR
#     where to put error message
ERRDIR=$TOPDIR/FleshBasic/ErrDir
export ERRDIR

#
#  don't touch below.
#  if used from script, we skip the next lines.
if [ $# -eq  0 ] ; then
    confirm  $PARAMDIR
    confirm  $OUTDIR
    confirm  $ERRDIR
    confirm  $EXECDIR
#       set ORIGIN
    source ../setupenv.sh
    source  ../../$ORIGIN/Smash/setupenv.sh  $0
    if [ -f ../../$ORIGIN/$FLESHDIR/Sparam ]; then
	cp ../../$ORIGIN/$FLESHDIR/Sparam  ./
	primaryf=` awk '$1=="PRIMARYFILE" {i1=index($0, qm) ;i2=index(substr($0, i1+1), " "); print substr($0, i1+1,i2-1)}' qm="'" Sparam `
	echo "'"$primaryf"' seems to be the primary file used at SkelFlesh."
	echo "Now it is copied to this directory"
	cp  ../../$ORIGIN/$FLESHDIR/$primaryf ./
    else
	echo "There is no 'Sparam' file in the original $FLESDIR"
        echo "something wrong"
	exit 1
    fi
fi
